@@ -1,6 +1,6 @@
 from functools import partial
 from pathlib import Path
-import warnings
+import logging
 import pandas
 import itertools
 import re
@@ -12,6 +12,8 @@ from .errors import DataJointError
 from .settings import config
 from .utils import safe_write
 
+logger = logging.getLogger(__name__.split(".")[0])
+
 
 class key:
     """
@@ -133,6 +135,7 @@ def _flatten_attribute_list(primary_key, attrs):
 class Fetch:
     """
     A fetch object that handles retrieving elements from the table expression.
+
     :param expression: the QueryExpression object to fetch from.
     """
 
@@ -153,20 +156,18 @@ class Fetch:
         """
         Fetches the expression results from the database into an np.array or list of dictionaries and
         unpacks blob attributes.
-        :param attrs: zero or more attributes to fetch. If not provided, the call will return
-        all attributes of this relation. If provided, returns tuples with an entry for each attribute.
+
+        :param attrs: zero or more attributes to fetch. If not provided, the call will return all attributes of this
+                        relation. If provided, returns tuples with an entry for each attribute.
         :param offset: the number of tuples to skip in the returned result
         :param limit: the maximum number of tuples to return
-        :param order_by: a single attribute or the list of attributes to order the results.
-                No ordering should be assumed if order_by=None.
-                To reverse the order, add DESC to the attribute name or names: e.g. ("age DESC", "frequency")
-                To order by primary key, use "KEY" or "KEY DESC"
-        :param format: Effective when as_dict=None and when attrs is empty
-                None: default from config['fetch_format'] or 'array' if not configured
-                "array": use numpy.key_array
-                "frame": output pandas.DataFrame. .
-        :param as_dict: returns a list of dictionaries instead of a record array.
-                Defaults to False for .fetch() and to True for .fetch('KEY')
+        :param order_by: a single attribute or the list of attributes to order the results. No ordering should be assumed
+                        if order_by=None. To reverse the order, add DESC to the attribute name or names: e.g. ("age DESC",
+                        "frequency") To order by primary key, use "KEY" or "KEY DESC"
+        :param format: Effective when as_dict=None and when attrs is empty None: default from config['fetch_format'] or
+                        'array' if not configured "array": use numpy.key_array "frame": output pandas.DataFrame. .
+        :param as_dict: returns a list of dictionaries instead of a record array. Defaults to False for .fetch() and to
+                        True for .fetch('KEY')
         :param squeeze:  if True, remove extra dimensions from arrays
         :param download_path: for fetches that download data, e.g. attachments
         :return: the contents of the relation in the form of a structured numpy.array or a dict list
@@ -210,7 +211,7 @@ class Fetch:
                 )
 
         if limit is None and offset is not None:
-            warnings.warn(
+            logger.warning(
                 "Offset set, but no limit. Setting limit to a large number. "
                 "Consider setting a limit explicitly."
             )
@@ -294,6 +295,7 @@ class Fetch:
 class Fetch1:
     """
     Fetch object for fetching the result of a query yielding one row.
+
     :param expression: a query expression to fetch from.
     """
 
