@@ -3,6 +3,9 @@ import pkg_resources
 from pathlib import Path
 from cryptography.exceptions import InvalidSignature
 from otumat import hash_pkg, verify
+import logging
+
+logger = logging.getLogger(__name__.split(".")[0])
 
 
 def _update_error_stack(plugin_name):
@@ -12,13 +15,13 @@ def _update_error_stack(plugin_name):
         plugin_meta = pkg_resources.get_distribution(plugin_name)
 
         data = hash_pkg(pkgpath=str(Path(plugin_meta.module_path, plugin_name)))
-        signature = plugin_meta.get_metadata("{}.sig".format(plugin_name))
-        pubkey_path = str(Path(base_meta.egg_info, "{}.pub".format(base_name)))
+        signature = plugin_meta.get_metadata(f"{plugin_name}.sig")
+        pubkey_path = str(Path(base_meta.egg_info, f"{base_name}.pub"))
         verify(pubkey_path=pubkey_path, data=data, signature=signature)
-        print("DataJoint verified plugin `{}` detected.".format(plugin_name))
+        logger.info(f"DataJoint verified plugin `{plugin_name}` detected.")
         return True
     except (FileNotFoundError, InvalidSignature):
-        print("Unverified plugin `{}` detected.".format(plugin_name))
+        logger.warning(f"Unverified plugin `{plugin_name}` detected.")
         return False
 
 
