@@ -46,10 +46,11 @@ default = dict(
         "display.show_tuple_count": True,
         "database.use_tls": None,
         "enable_python_native_blobs": True,  # python-native/dj0 encoding support
+        "filepath_checksum_size_limit": None,  # file size limit for when to disable checksums
     }
 )
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger(__name__.split(".")[0])
 log_levels = {
     "INFO": logging.INFO,
     "WARNING": logging.WARNING,
@@ -97,17 +98,19 @@ class Config(collections.abc.MutableMapping):
     def save(self, filename, verbose=False):
         """
         Saves the settings in JSON format to the given file path.
+
         :param filename: filename of the local JSON settings file.
         :param verbose: report having saved the settings file
         """
         with open(filename, "w") as fid:
             json.dump(self._conf, fid, indent=4)
         if verbose:
-            print("Saved settings in " + filename)
+            logger.info("Saved settings in " + filename)
 
     def load(self, filename):
         """
         Updates the setting from config file in JSON format.
+
         :param filename: filename of the local JSON settings file. If None, the local config file is used.
         """
         if filename is None:
@@ -238,8 +241,8 @@ class Config(collections.abc.MutableMapping):
             return self._conf[key]
 
         def __setitem__(self, key, value):
-            logger.log(
-                logging.INFO, "Setting {0:s} to {1:s}".format(str(key), str(value))
+            logger.debug(
+                logging.DEBUG, "Setting {0:s} to {1:s}".format(str(key), str(value))
             )
             if validators[key](value):
                 self._conf[key] = value
