@@ -7,7 +7,6 @@ import pandas
 import logging
 import uuid
 import re
-import warnings
 from pathlib import Path
 from .settings import config
 from .declare import declare, alter
@@ -25,7 +24,7 @@ from .errors import (
 )
 from .version import __version__ as version
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger(__name__.split(".")[0])
 
 foreign_key_error_regexp = re.compile(
     r"[\w\s:]*\((?P<child>`[^`]+`.`[^`]+`), "
@@ -82,6 +81,7 @@ class Table(QueryExpression):
     def declare(self, context=None):
         """
         Declare the table in the schema based on self.definition.
+
         :param context: the context for foreign key resolution. If None, foreign keys are
             not allowed.
         """
@@ -159,6 +159,7 @@ class Table(QueryExpression):
 
     def parents(self, primary=None, as_objects=False, foreign_key_info=False):
         """
+
         :param primary: if None, then all parents are returned. If True, then only foreign keys composed of
             primary key attributes are considered.  If False, return foreign keys including at least one
             secondary attribute.
@@ -180,6 +181,7 @@ class Table(QueryExpression):
 
     def children(self, primary=None, as_objects=False, foreign_key_info=False):
         """
+
         :param primary: if None, then all children are returned. If True, then only foreign keys composed of
             primary key attributes are considered.  If False, return foreign keys including at least one
             secondary attribute.
@@ -201,6 +203,7 @@ class Table(QueryExpression):
 
     def descendants(self, as_objects=False):
         """
+
         :param as_objects: False - a list of table names; True - a list of table objects.
         :return: list of tables descendants in topological order.
         """
@@ -212,6 +215,7 @@ class Table(QueryExpression):
 
     def ancestors(self, as_objects=False):
         """
+
         :param as_objects: False - a list of table names; True - a list of table objects.
         :return: list of tables ancestors in topological order.
         """
@@ -224,6 +228,7 @@ class Table(QueryExpression):
     def parts(self, as_objects=False):
         """
         return part tables either as entries in a dict with foreign key informaiton or a list of objects
+
         :param as_objects: if False (default), the output is a dict describing the foreign keys. If True, return table objects.
         """
         nodes = [
@@ -270,16 +275,20 @@ class Table(QueryExpression):
 
     def update1(self, row):
         """
-        update1 updates one existing entry in the table.
-        Caution: In DataJoint the primary modes for data manipulation is to ``insert`` and ``delete``
-        entire records since referential integrity works on the level of records, not fields.
-        Therefore, updates are reserved for corrective operations outside of main workflow.
-        Use UPDATE methods sparingly with full awareness of potential violations of assumptions.
+        ``update1`` updates one existing entry in the table.
+        Caution: In DataJoint the primary modes for data manipulation is to ``insert`` and
+        ``delete`` entire records since referential integrity works on the level of records,
+        not fields. Therefore, updates are reserved for corrective operations outside of main
+        workflow. Use UPDATE methods sparingly with full awareness of potential violations of
+        assumptions.
 
         :param row: a ``dict`` containing the primary key values and the attributes to update.
-        Setting an attribute value to None will reset it to the default value (if any)
+            Setting an attribute value to None will reset it to the default value (if any).
+
         The primary key attributes must always be provided.
+
         Examples:
+
         >>> table.update1({'id': 1, 'value': 3})  # update value in record with id=1
         >>> table.update1({'id': 1, 'value': None})  # reset value to default
         """
@@ -301,7 +310,7 @@ class Table(QueryExpression):
             raise DataJointError("Update cannot be applied to a restricted table.")
         key = {k: row[k] for k in self.primary_key}
         if len(self & key) != 1:
-            raise DataJointError("Update entry must exist.")
+            raise DataJointError("Update can only be applied to one existing entry.")
         # UPDATE query
         row = [
             self.__make_placeholder(k, v)
@@ -320,7 +329,7 @@ class Table(QueryExpression):
         Insert one data record into the table. For ``kwargs``, see ``insert()``.
 
         :param row: a numpy record, a dict-like object, or an ordered sequence to be inserted
-        as one row.
+            as one row.
         """
         self.insert((row,), **kwargs)
 
@@ -333,15 +342,18 @@ class Table(QueryExpression):
         allow_direct_insert=None,
     ):
         """
-            Insert a collection of rows.
-            :param rows: An iterable where an element is a numpy record, a dict-like object, a
-                pandas.DataFrame, a sequence, or a query expression with the same heading as self.
-            :param replace: If True, replaces the existing tuple.
-            :param skip_duplicates: If True, silently skip duplicate inserts.
-            :param ignore_extra_fields: If False, fields that are not in the heading raise error.
-            :param allow_direct_insert: applies only in auto-populated tables.
-        If False (default), insert are allowed only from inside the make callback.
-            Example::
+        Insert a collection of rows.
+
+        :param rows: An iterable where an element is a numpy record, a dict-like object, a
+            pandas.DataFrame, a sequence, or a query expression with the same heading as self.
+        :param replace: If True, replaces the existing tuple.
+        :param skip_duplicates: If True, silently skip duplicate inserts.
+        :param ignore_extra_fields: If False, fields that are not in the heading raise error.
+        :param allow_direct_insert: applies only in auto-populated tables. If False (default),
+            insert are allowed only from inside the make callback.
+
+        Example:
+
             >>> relation.insert([
             >>>     dict(subject_id=7, species="mouse", date_of_birth="2014-09-01"),
             >>>     dict(subject_id=8, species="mouse", date_of_birth="2014-09-02")])
@@ -451,11 +463,9 @@ class Table(QueryExpression):
         """
         Deletes the contents of the table and its dependent tables, recursively.
 
-        :param transaction: if True, use the entire delete becomes an atomic transaction.
-            This is the default and recommended behavior. Set to False if this delete is nested
-            within another transaction.
-        :param safemode: If True, prohibit nested transactions and prompt to confirm. Default
-            is dj.config['safemode'].
+        :param transaction: if True, use the entire delete becomes an atomic transaction. This is the default and
+                            recommended behavior. Set to False if this delete is nested within another transaction.
+        :param safemode: If True, prohibit nested transactions and prompt to confirm. Default is dj.config['safemode'].
         :param force_parts: Delete from parts even when not deleting from their masters.
         :return: number of deleted rows (excluding those from dependent tables)
         """
@@ -521,7 +531,7 @@ class Table(QueryExpression):
                     cascade(child)
                 else:
                     deleted.add(table.full_table_name)
-                    print(
+                    logger.info(
                         "Deleting {count} rows from {table}".format(
                             count=delete_count, table=table.full_table_name
                         )
@@ -757,7 +767,7 @@ class Table(QueryExpression):
         >>> (v2p.Mice() & key)._update('mouse_dob', '2011-01-01')
         >>> (v2p.Mice() & key)._update( 'lens')   # set the value to NULL
         """
-        warnings.warn(
+        logger.warning(
             "`_update` is a deprecated function to be removed in datajoint 0.14. "
             "Use `.update1` instead."
         )
@@ -796,6 +806,7 @@ class Table(QueryExpression):
         For a given attribute `name` with `value`, return its processed value or value placeholder
         as a string to be included in the query and the value, if any, to be submitted for
         processing by mysql API.
+
         :param name:  name of attribute to be inserted
         :param value: value of attribute to be inserted
         """
@@ -852,6 +863,7 @@ class Table(QueryExpression):
     def __make_row_to_insert(self, row, field_list, ignore_extra_fields):
         """
         Helper function for insert and update
+
         :param row:  A tuple to insert
         :return: a dict with fields 'names', 'placeholders', 'values'
         """
@@ -859,6 +871,7 @@ class Table(QueryExpression):
         def check_fields(fields):
             """
             Validates that all items in `fields` are valid attributes in the heading
+
             :param fields: field names of a tuple
             """
             if not field_list:
@@ -923,6 +936,7 @@ class Table(QueryExpression):
 def lookup_class_name(name, context, depth=3):
     """
     given a table name in the form `schema_name`.`table_name`, find its class in the context.
+
     :param name: `schema_name`.`table_name`
     :param context: dictionary representing the namespace
     :param depth: search depth into imported modules, helps avoid infinite recursion.
@@ -977,6 +991,7 @@ class FreeTable(Table):
     """
     A base relation without a dedicated class. Each instance is associated with a table
     specified by full_table_name.
+
     :param conn:  a dj.Connection object
     :param full_table_name: in format `database`.`table_name`
     """
@@ -1007,6 +1022,7 @@ class Log(Table):
     """
     The log table for each schema.
     Instances are callable.  Calls log the time and identifying information along with the event.
+
     :param skip_logging: if True, then log entry is skipped by default. See __call__
     """
 
@@ -1048,6 +1064,7 @@ class Log(Table):
 
     def __call__(self, event, skip_logging=None):
         """
+
         :param event: string to write into the log table
         :param skip_logging: If True then do not log. If None, then use self.skip_logging
         """
@@ -1070,6 +1087,7 @@ class Log(Table):
     def delete(self):
         """
         bypass interactive prompts and cascading dependencies
+
         :return: number of deleted items
         """
         return self.delete_quick(get_count=True)
